import { createApp } from 'vue';
import { createPinia } from 'pinia';
import Antd, {message} from 'ant-design-vue';
import 'ant-design-vue/dist/reset.css';
import naive from 'naive-ui'
// 通用字体
import 'vfonts/Lato.css'
// 等宽字体
import 'vfonts/FiraCode.css'

const baseColor = 'border-radius: 3px; padding: 2px 3px; font-family: consolas'
window.consoleColor = {
    ipcMessage: {
        IN: 'color: #ffffff; background: #ff7f50;' + baseColor,
        TO: 'color: #000000; background: #ff7f50;' + baseColor,
    },
    ipcInvoke: {
        IN: 'color: #ffffff; background: #ffa502;' + baseColor,
        TO: 'color: #000000; background: #ffa502;' + baseColor,
    },
    router: {
        IN: 'color: #ffffff; background: #2273b2;' + baseColor,
        TO: "color: #eb3650; background: #2273b2;" + baseColor
    },
    wsRequest: {
        IN: "color: #fefefe; background: #2ed573;" + baseColor,
        TO: "color: #000000; background: #2ed573;" + baseColor
    },
    wsServer: {
        IN: 'color: #fefefe; background: #7bed9f;' + baseColor,
        TO: 'color: #000000; background: #7bed9f;' + baseColor,
    },
}

import '@/assets/main.css'
import App from '@/App.vue'
import createRoutering from '@/router/index.js';
import authRouter from '@/router/authorization.js';

const app = createApp(App);

const pinia = createPinia();
app.use(pinia);
const router = createRoutering();
app.use(router);
app.use(authRouter, {
    router,
});
app.use(Antd);
app.use(naive);

message.config({
    top: `200px`,
    duration: 2,
    maxCount: 3,
})
app.provide('message', message);

app.mount('#app');

