// | ------------------------------------------------------------
// | @版本: version 0.1
// | @创建人: 【Nie-x7129】
// | @E-mail: x71291@outlook.com
// | @所在项目: js-ii-pad-linux
// | @文件描述: ipc.js -
// | @创建时间: 2024-11-04 14:31
// | @更新时间: 2024-11-04 14:31
// | @修改记录:
// | -*-*-*-  (时间--修改人--修改说明)  -*-*-*-
// | =
// | ------------------------------------------------------------

import {reactive} from "vue";
import {defineStore} from 'pinia';
import {useSystemStore} from "@/stores/system.js";
import api from "@/api/index.js";

const IPC_NAME = import.meta.env.VITE_ELECTRON_IPC_MESSAGE_NAME
const MAIN_NAME = import.meta.env.VITE_ELECTRON_MAIN_MESSAGE_NAME
export const useIpcStore = defineStore('ipc', () => {
    const state = reactive({
        // 服务器地址状态
        serverHostInit: 0,
        serverHost: null,
    });

    window?.ipcRenderer?.on(MAIN_NAME, (_event, message) => {
        if (!message.type) {
            return console.log('未知进程消息：', message)
        }
        console.log('%c===>> IPC_MESSAGE ', consoleColor.ipcMessage.TO,message)
        switch (message.type) {
            case '/init/serverHost':
                // 有服务器地址传回
                if (message.data.status === 0) {
                    state.serverHostInit = 1;
                    state.serverHost = message.data.serverHost;
                } else if (message.data.status === -1) {
                    if (state.serverHostInit !== 1) {
                        state.serverHostInit = -1;
                    }
                }
                console.log('ABC')
                break;
            case '/init/deviceBindingInfo':
                const systemStore = useSystemStore();
                if(message.data.status === 0){
                    systemStore.setDeviceBinding(message.data.deviceBinding, true);
                }
                break;
            default:
                console.log('IPC UNKNOW', message)
                break;
        }
    })

    // 告诉主线程，初始化成功
    const initRender = () => {
        console.log('%c<<=== IPC_MESSAGE ', consoleColor.ipcMessage.IN, 'Started')
        window?.ipcRenderer?.send(IPC_NAME, {
            type: 'Started',
            data: {
                msg: 'Init ok!'
            }
        })
    }
    // 修改渲染器服务器地址状态
    const setRenderServerHostState = (status = -1) => {
        state.serverHostInit = status
    }

    // 设置有效的服务器地址
    const setValidServerAddress = async (host) => {
        await api.initIpc.setServerHost({host})
        state.serverHostInit = 1;
        state.serverHost = host;
    }

    return {state, initRender, setRenderServerHostState, setValidServerAddress}
})
