// | ------------------------------------------------------------
// | @版本: version 0.1
// | @创建人: 【Nie-x7129】
// | @E-mail: x71291@outlook.com
// | @所在项目: js-ii-pad-linux
// | @文件描述: system.js -
// | @创建时间: 2024-11-04 14:06
// | @更新时间: 2024-11-04 14:06
// | @修改记录:
// | -*-*-*-  (时间--修改人--修改说明)  -*-*-*-
// | =
// | ------------------------------------------------------------

import {reactive} from 'vue';
import {defineStore} from 'pinia';
import {useIpcStore} from "@/stores/ipc.js";
import api from "@/api/index.js";


export const useSystemStore = defineStore('system', () => {
    const localStore = {
        checkedUserList: localStorage.getItem('checkedUserList') === null ? [] : JSON.parse(localStorage.getItem('checkedUserList')),
    }
    const state = reactive({
        name: 'systemStore',
        // * 路由白名单
        routeWhiteList: ['/', '/signin'],
        // * 接口白名单
        apiWhiteList: ['/authUser/sign/in'],
        // * 默认跳转路由
        defaultRoute: import.meta.env.VITE_HOME_REDIRECT,
        // * 标题
        title: import.meta.env.VITE_TITLE,
        // * 组件默认大小
        componentSize: 'large',
        // * 主页地址
        homePath: '/home',
        // * 在线用户列表
        onlineUserList: [],
        // * 当前选中的用户
        nowFocusUser: {},
        // * 系统名称
        systemName: import.meta.env.VITE_SYSTEM_NAME,
        // * 设备绑定信息
        deviceBinding: undefined,
        // * 记住密码列表
        checkedUserList: localStore.checkedUserList,
        // * 网络状态
        networkStatus: true,
        // * 生产计划
        productionBatch: null,
        // * 公用报工参数
        reportParam: {},
        // * 工序队列
        reportQueue: {},
        // * 工序队列变化值
        reportQueueChange: 0,
    })


    // * 设置当前选中用户
    const setFocusUser = (data) => {
        state.nowFocusUser = data
    }

    // * 新增在线用户
    const setNewOnlineUser = (data) => {
        state.onlineUserList.push(data)
    }
    // * 覆盖在线用户
    const copyOnlineUser  = (data) => {
        state.onlineUserList = (data)
    }

    // * 退出登录指定用户
    const logoutUser = (username) => {
        let userCount;
        state.onlineUserList.forEach((user, index) => {
            if (user.username === username) {
                userCount = index
            }
        })
        state.onlineUserList.splice(userCount, 1)
    }
    // * 设置设备信息
    const setDeviceBinding = async (deviceBinding) => {
        await api.deviceIpc.setDeviceBinding(deviceBinding)
        state.deviceBinding = deviceBinding
    }
    // * 新增用户信息库
    const addUserInfo = (user) => {
        const checkedUserList = state.checkedUserList
        checkedUserList.push(user)
        localStorage.setItem('checkedUserList', JSON.stringify(checkedUserList))
    }

    // * 设置用户的工序
    const setUserProcessList = (processList) => {
        state.nowFocusUser.defaultProcessList = processList
    }

    // * 设置生产计划
    const setProductionBatch = (batch) => {
        state.productionBatch = batch
    }

    // * 添加报工参数
    const addReportParam = (key, value) => {
        state.reportParam[key] = value
    }

    // * 改变工序队列
    const handleChangeReportQueue = (key, value) => {
        state.reportQueue[key] = value
        state.reportQueueChange = new Date().getTime()
    }

    return {
        state,
        setFocusUser,
        setNewOnlineUser,
        logoutUser,
        setDeviceBinding,
        addUserInfo,
        copyOnlineUser,
        setUserProcessList,
        setProductionBatch,
        addReportParam,
        handleChangeReportQueue
    }
})
