// | ------------------------------------------------------------
// | @版本: version 0.1
// | @创建人: 【Nie-nie】
// | @E-mail: x71291@outlook.com
// | @所在项目: js-ii-pad-linux
// | @文件描述: ws.js -
// | @创建时间: 2024-11-26 17:05
// | @更新时间: 2024-11-26 17:05
// | @修改记录:
// | -*-*-*-  (时间--修改人--修改说明)  -*-*-*-
// | =
// | ------------------------------------------------------------
import {defineStore} from "pinia";
import {inject, reactive} from "vue";
import {v4 as getUUID} from 'uuid';
import {sleep} from "@/tools/sleep.js";
import {message} from "ant-design-vue";
import {useSystemStore} from "@/stores/system.js";

const Message = message

class MyWebSocket {
    // 实时请求池
    #requestPool = {};
    // websocket客户端
    #mwsc = null;
    // 请求默认超时时间
    #requestTimeout = 10000;
    // ws默认地址
    #host = '10.10.10.10';
    // 外部的state状态值
    #state = undefined;
    // 相当于token的东西
    #deviceInfo = undefined;
    // 重复启动不会重复发心跳
    #heartStatus = 0;
    // 正在启动
    #starting = false;

    constructor(options = {host: '10.10.10.10', requestTimeout: 10000}, state) {
        if (options.requestTimeout) {
            this.#requestTimeout = options.requestTimeout;
        }
        if (options.host) {
            this.#host = options.host;
        }
        this.#state = state;
        const systemStore = useSystemStore();
        this.#deviceInfo = systemStore.state.deviceBinding;
        this.createServer()
    }

    createServer() {
        if(this.#starting){
            return ;
        }
        return new Promise((resolve, reject) => {
            // console.log('正在启动WS')
            this.#starting = true;
            const wsc = new WebSocket(`ws://${this.#host}:38610`);
            this.#heart()
            this.#heartStatus = 1;
            wsc.onopen = () => {
                this.#starting = false;
                // console.log("wsc open");
                this.#state.wsState = 1;
                resolve();
            }
            wsc.onclose = () => {
                this.#starting = false;
                console.log("wsc close");
                this.#state.wsState = -1;
                reject('wsc closed');
            }
            wsc.onerror = (e) => {
                // console.log("wsc error:", e)
                this.#state.wsState = -1;
                reject("wsc error:", e);
            }
            wsc.onmessage = (msg) => {
                let message = undefined;
                // console.log("wsc message:", msg);
                try {
                    message = JSON.parse(msg.data);
                } catch (err) {
                    console.log('ws响应数据不合法，无法转换为Object')
                }
                if (!message) {
                    return
                }

                if (message.type === 'realTimeRequest') {
                    if (Object.keys(this.#requestPool).includes(message.uuid)) {
                        clearTimeout(this.#requestPool[message.uuid].timeout);
                        this.#requestPool[message.uuid].end(message);
                    }
                }else if(message.type === 'simpleRequest') {
                    console.log(`%c===>> WS-Sim : ${message.path}`,consoleColor.wsServer.IN, message.data || '');
                    const ctx = {
                        data: message,
                        reply: data => {
                            try{
                                console.log(`%c<<=== WS-Sim : ${message.path}`,consoleColor.wsServer.TO, data || '');
                                this.#mwsc.send(JSON.stringify({
                                    ...message,
                                    data,
                                }));
                            }catch (e) {
                                console.log(`wsc server callback Error`, e)
                            }
                        }
                    }
                    ctx.reply(this.#simpleRequestServer(ctx));
                }
            }
            this.#mwsc = wsc;
        })
    }

    async #heart() {
        const systemStore = useSystemStore();
        if (this.#heartStatus !== 0) {
            return;
        }
        // 心跳请求，每5秒发送一次，不间断
        let heartNumber = 0;
        let heartErrorNumber = 0;
        await sleep(1000);
        const sendHeart = () => {
            if(heartErrorNumber >= 2){
                systemStore.state.networkStatus = false;
            }else{
                systemStore.state.networkStatus = true;
            }
            this.request('/heart', {
                heartNumber: heartNumber++, timestamp: new Date().getTime(),
            }, 3000).then(res => {
                heartErrorNumber = 0;
            }, err => {
                heartErrorNumber++;
                console.log('wsc 心跳发送失败: ', heartErrorNumber);
            })
        }
        sendHeart();
        setInterval(() => {
            sendHeart();
        }, 5000)
    }

    // 等待存活
    async #awaitSurvival(){
        if (this.#mwsc.readyState !== 1) {
            if (this.#mwsc.readyState === 2) {
                for (let i = 0; i < 5; i++) {
                    await sleep(1000);
                }
            }
            await sleep(1000);
            if (this.#mwsc.readyState !== 1) {
                this.#mwsc?.close();
                console.log('ws已断开, 正在重启！！！');
                await this.createServer()
            }
        } else if (this.#mwsc.readyState === 0) {
            for (let i = 0; i < 5; i++) {
                await sleep(1000);
                if (this.#mwsc.readyState === 1) {
                    break;
                }
            }
        }
    }

    request = (path, data, timeout = undefined) => {
        return new Promise(async (resolve, reject) => {
            if (!['/heart'].includes(path)) {
                console.log(`%c<<=== WS-Req : ${path}`,consoleColor.wsRequest.IN, data || '');
            }
            const uuid = getUUID();
            this.#requestPool[uuid] = {
                uuid: uuid,
                request: data,
                timeout: setTimeout(() => {
                    delete this.#requestPool[uuid]
                    reject(`timeout : ${path}`)
                }, timeout === undefined ? this.#requestTimeout : timeout),
                end: (response) => {
                    if (!['/heart'].includes(path)) {
                        console.log(`%c===>> WS-Req : ${path}`, consoleColor.wsRequest.TO, response.data);
                    }
                    delete this.#requestPool[uuid];
                    if (response.code !== 200) {
                        console.log('实时消息错误', response.message);
                        Message.warn(response.message);
                        reject(response);
                    } else {
                        resolve(response);
                    }
                }
            }
            await this.#awaitSurvival()
            try {
                const requestDataStringify = JSON.stringify({
                    type: "realTimeRequest", uuid: uuid, path: path, data: data, license: {
                        deviceInfo: this.#deviceInfo
                    }
                })
                this.#mwsc.send(requestDataStringify);
            } catch (err) {
                console.log('wsc 消息发送失败:', err);
            }
        })
    }

    // 作为服务端的响应
    #simpleRequestServer(ctx){
        const systemStore = useSystemStore();
        switch(ctx.data.path) {
            case '/report': {
                console.log('???')
                console.log(ctx.data)
                systemStore.state.reportQueue[ctx.data.data.processId]
                systemStore.state.reportQueue[ctx.data.data.processId]?.push(ctx.data.data)
                systemStore.state.reportQueueChange = new Date().getTime();
                return 'ok'
            }
        }
    }
}


export const useWSStore = defineStore('ws', () => {
    const state = reactive({
        wsState: 0, // 0是默认状态，未启动，1是正常启动状态， -1是出错状态
        wsc: undefined, // wsc客户端
    })

    // 连接服务器
    const connectWebSocketServer = (host = '10.10.10.10') => {
        if (state.wsState === 1) {
            return;
        }
        const mwsc = new MyWebSocket({host: host}, state);
        state.wsc = mwsc;
    }

    const wsMethod = {
        // 登录
        login: data => state.wsc.request('/login', data), // 退出登录
        logout: data => state.wsc.request('/login/logout', data), // 获取当前设备上登陆的用户
        getDeviceUserList: data => state.wsc.request('/login/getDeviceUserList', data), // 获取用户的登陆设备列表
        getUserLoginDeviceList: data => state.wsc.request('/login/getUserLoginDeviceList', data),

        // 获取当前产线生产批次
        getProductionBatch: () => state.wsc.request('/production/getProductionBatch'),
        // 获取当前计划的pad的工序
        getProductionRouteByRouteIdAndIpcId: data => state.wsc.request('/production/getProductionRouteByRouteIdAndIpcId', data),

        // 保存用户默认工序
        setUserDefaultProcessList: data => state.wsc.request('/production/setUserDefaultProcessList', data),

        // 获取报工参数
        getReportParam: data => state.wsc.request('/production/getReportParam', data),

        // 正常报工
        addProductionReport: data => state.wsc.request('/production/addProductionReport', data),

        // 获取当前工序的队列
        getReportQueue: data => state.wsc.request('/production/getReportQueue', data),

        // 湖区当前产线流水号
        getWorklineSerial: data => state.wsc.request('/production/getWorklineSerial', data),
    }

    const onWsConnect = async (callback) => {
        for (let i = 0; i < 5; i++) {
            if(state.wsState === 1) {
                callback()
                break;
            }else{
                await sleep(200);
            }
        }
    }

    return {state, connectWebSocketServer, wsMethod, onWsConnect}
})
